@@ -66,6 +66,7 @@ CommandLine::CommandLine(void)
 , recoveryblockcount(0)
 , recoveryblockcountset(false)
 , redundancy(0)
+, redundancysize(0)
 , redundancyset(false)
 , parfilename()
 , extrafiles()
@@ -692,6 +693,7 @@ bool CommandLine::Parse(int argc, char *argv[])
         string name;
         DiskFile::SplitFilename(argv[0], path, name);
         filenames = DiskFile::FindFiles(path, name, recursive);
+        string canonicalBasepath = DiskFile::GetCanonicalPathname(basepath);
 
         list<string>::iterator fn = filenames->begin();
         while (fn != filenames->end())
@@ -707,6 +709,11 @@ bool CommandLine::Parse(int argc, char *argv[])
           {
             cout << "Ignoring non-existent source file: " << filename << endl;
           }
+          // skip files outside basepath
+          else if (filename.find(canonicalBasepath) == string::npos)
+          {
+                cout << "Ignoring out of basepath source file: " << filename << endl;
+          }
           else
           {
             u64 filesize = DiskFile::GetFileSize(filename);
