@@ -67,6 +67,17 @@ bool DiskFile::Create(string _filename, u64 _filesize)
   filename = _filename;
   filesize = _filesize;
 
+  // do we have a path separator in the filename ?
+  string::size_type where;
+  if (string::npos != (where = filename.find_last_of('/')) ||
+      string::npos != (where = filename.find_last_of('\\')))
+  {
+    string path, name;
+    DiskFile::SplitFilename(filename, path, name);
+
+    CreateDirectory(path.c_str(), NULL);
+  }
+
   // Create the file
   hFile = ::CreateFileA(_filename.c_str(), GENERIC_READ | GENERIC_WRITE, 0, NULL, CREATE_NEW, 0, NULL);
   if (hFile == INVALID_HANDLE_VALUE)
@@ -354,12 +365,7 @@ list<string>* DiskFile::FindFiles(string path, string wildcard, bool recursive)
         string nwwildcard="*";
         dirmatches = DiskFile::FindFiles(fd.cFileName, nwwildcard, true);
 
-        list<string>::iterator fn = dirmatches->begin();
-        while (fn != dirmatches->end())
-        {
-          matches->push_back(*fn);
-          ++fn;
-        }
+        matches->merge(*dirmatches);
       }
     } while (::FindNextFile(h, &fd));
     ::FindClose(h);
@@ -428,6 +434,21 @@ bool DiskFile::Create(string _filename, u64 _filesize)
   filename = _filename;
   filesize = _filesize;
 
+  // do we have a path separator in the filename ?
+  string::size_type where;
+  if (string::npos != (where = filename.find_last_of('/')) ||
+      string::npos != (where = filename.find_last_of('\\')))
+  {
+    string path, name;
+    DiskFile::SplitFilename(filename, path, name);
+
+    struct stat st;
+    if (! (stat(path.c_str(), &st) == 0 && S_ISDIR(st.st_mode)))
+    {
+      mkdir(path.c_str(), S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
+    }
+  }
+
   file = fopen(_filename.c_str(), "wb");
   if (file == 0)
   {
@@ -704,12 +725,7 @@ list<string>* DiskFile::FindFiles(string path, string wildcard, bool recursive)
                 string nwwildcard="*";
                 dirmatches = DiskFile::FindFiles(fn, nwwildcard, true);
 
-                list<string>::iterator fn = dirmatches->begin();
-                while (fn != dirmatches->end())
-                {
-                  matches->push_back(*fn);
-                  ++fn;
-                }
+                matches->merge(*dirmatches);
               }
               else if (S_ISREG(st.st_mode))
               {
@@ -746,12 +762,7 @@ list<string>* DiskFile::FindFiles(string path, string wildcard, bool recursive)
                   string nwwildcard="*";
                   dirmatches = DiskFile::FindFiles(fn, nwwildcard, true);
 
-                  list<string>::iterator fn = dirmatches->begin();
-                  while (fn != dirmatches->end())
-                  {
-                    matches->push_back(*fn);
-                    ++fn;
-                  }
+                  matches->merge(*dirmatches);
                 }
                 else if (S_ISREG(st.st_mode))
                 {
@@ -780,12 +791,7 @@ list<string>* DiskFile::FindFiles(string path, string wildcard, bool recursive)
         string nwwildcard="*";
         dirmatches = DiskFile::FindFiles(fn, nwwildcard, true);
 
-        list<string>::iterator fn = dirmatches->begin();
-        while (fn != dirmatches->end())
-        {
-          matches->push_back(*fn);
-          ++fn;
-        }
+        matches->merge(*dirmatches);
       }
       else if (S_ISREG(st.st_mode))
       {
